summaryrefslogtreecommitdiffstats
path: root/perl-install/partition_table
diff options
context:
space:
mode:
authorAhmad Samir <ahmad@mageia.org>2011-04-02 19:39:51 +0000
committerAhmad Samir <ahmad@mageia.org>2011-04-02 19:39:51 +0000
commitb669b354a83790133e9d1be5c7796594bf9cfe22 (patch)
treeaa0ec2ee89a4aee11369bb5ebb3f3997526438b3 /perl-install/partition_table
parent14d4269e46245ec89e8106428f558973b127d3b2 (diff)
downloaddrakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.gz
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.bz2
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.xz
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.zip
- use 'cannot' instead of 'can not'
- use 'LDAP' instead of 'Ldap'
Diffstat (limited to 'perl-install/partition_table')
-rw-r--r--perl-install/partition_table/raw.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/perl-install/partition_table/raw.pm b/perl-install/partition_table/raw.pm
index c2430f703..09a0137e7 100644
--- a/perl-install/partition_table/raw.pm
+++ b/perl-install/partition_table/raw.pm
@@ -273,7 +273,7 @@ sub pt_info_to_primary {
#- try writing what we've just read, yells if it fails
#- testing on last sector of head #0 (unused in 99% cases)
#-
#- return false if the device can not be written to (especially for Smartmedia)
sub test_for_bad_drives {
my ($hd) = @_;
@@ -282,19 +282,19 @@ sub test_for_bad_drives {
sub error { die "$_[0] error: $_[1]" }
- my $F = openit($hd, $::testing ? 0 : 2) or error(openit($hd) ? 'write' : 'read', "can not open device");
+ my $F = openit($hd, $::testing ? 0 : 2) or error(openit($hd) ? 'write' : 'read', "cannot open device");
my $seek = sub {
c::lseek_sector(fileno($F), $sector, 0) or error('read', "seeking to sector $sector failed");
};
my $tmp;
- &$seek; sysread $F, $tmp, $SECTORSIZE or error('read', "can not even read ($!)");
+ &$seek; sysread $F, $tmp, $SECTORSIZE or error('read', "cannot even read ($!)");
return if $hd->{readonly} || $::testing;
- &$seek; syswrite $F, $tmp or error('write', "can not even write ($!)");
+ &$seek; syswrite $F, $tmp or error('write', "cannot even write ($!)");
my $tmp2;
- &$seek; sysread $F, $tmp2, $SECTORSIZE or die "test_for_bad_drives: can not even read again ($!)";
+ &$seek; sysread $F, $tmp2, $SECTORSIZE or die "test_for_bad_drives: cannot even read again ($!)";
$tmp eq $tmp2 or die
N("Something bad is happening on your drive.
A test to check the integrity of data has failed.
@@ -273,7 +273,7 @@ sub pt_info_to_primary {
#- testing on last sector of head #0 (unused in 99% cases)
#-
-#- return false if the device can not be written to (especially for Smartmedia)
+#- return false if the device cannot be written to (especially for Smartmedia)
sub test_for_bad_drives {
my ($hd) = @_;